s/PIDZone/DbusPidZone/g

Renamed PIDZone to DbusPidZone because this object builds in via
inheritance a Dbus implementation of the Mode control interface.

Signed-off-by: Patrick Venture <venture@google.com>
Change-Id: Ifc6c11db4952de5909f0e556c41ec25eee217408
diff --git a/pid/pidloop.hpp b/pid/pidloop.hpp
index cf4b7ce..c8365e3 100644
--- a/pid/pidloop.hpp
+++ b/pid/pidloop.hpp
@@ -12,12 +12,12 @@
  * This function calls itself indefinitely in an async loop to calculate
  * fan outputs based on thermal inputs.
  *
  * @param[in] zone - ptr to the PIDZone for this loop.
  * @param[in] timer - boost timer used for async callback.
  * @param[in] first - boolean to denote if initialization needs to be run.
  * @param[in] ms100cnt - loop timer counter.
  */
-void pidControlLoop(PIDZone* zone, boost::asio::steady_timer& timer,
+void pidControlLoop(DbusPidZone* zone, boost::asio::steady_timer& timer,
                     bool first = true, int ms100cnt = 0);
 
 } // namespace pid_control
@@ -12,12 +12,12 @@
  * fan outputs based on thermal inputs.
  *
- * @param[in] zone - ptr to the PIDZone for this loop.
+ * @param[in] zone - ptr to the DbusPidZone for this loop.
  * @param[in] timer - boost timer used for async callback.
  * @param[in] first - boolean to denote if initialization needs to be run.